shishi-commit
[Top][All Lists]
Advanced

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]

[SCM] GNU shishi branch, master, updated. shishi-1-0-2-40-g1afa1ee


From: Mats Erik Andersson
Subject: [SCM] GNU shishi branch, master, updated. shishi-1-0-2-40-g1afa1ee
Date: Sat, 05 Jul 2014 12:47:57 +0000

This is an automated email from the git hooks/post-receive script. It was
generated because a ref change was pushed to the repository containing
the project "GNU shishi".

http://git.savannah.gnu.org/cgit/shishi.git/commit/?id=1afa1ee89ab9a80cd79b0aeb36c0f47391795051

The branch, master has been updated
       via  1afa1ee89ab9a80cd79b0aeb36c0f47391795051 (commit)
      from  9771ff753aa23f70e9d4a7297b8a86494b366d36 (commit)

Those revisions listed above that are new to this repository have
not appeared on any other notification email; so we list those
revisions in full, below.

- Log -----------------------------------------------------------------
commit 1afa1ee89ab9a80cd79b0aeb36c0f47391795051
Author: Mats Erik Andersson <address@hidden>
Date:   Sat Jul 5 13:09:13 2014 +0200

    Integer types on 64-bit systems.
    
    Aurelien Jarno uncovered an issue in the Debian
    package of version 1.0.2 when libtasn1 expects
    an integer pointer. Use a variation and add
    another integer size fix.

-----------------------------------------------------------------------

Summary of changes:
 db/file.c                     |    4 ++--
 extra/pam_shishi/pam_shishi.c |    2 +-
 lib/asn1.c                    |    9 ++++++---
 3 files changed, 9 insertions(+), 6 deletions(-)

diff --git a/db/file.c b/db/file.c
index a6d09a1..acfcdfb 100644
--- a/db/file.c
+++ b/db/file.c
@@ -423,7 +423,7 @@ read_key (Shisa * dbh,
   Shisa_key tmpkey;
   FILE *fh;
   char *file;
-  unsigned passwdlen;
+  size_t passwdlen;
   char junk;
   int rc;
 
@@ -435,7 +435,7 @@ read_key (Shisa * dbh,
 
   memset (&tmpkey, 0, sizeof (tmpkey));
 
-  rc = fscanf (fh, "%u %u %u %u %u %u", &tmpkey.etype, &tmpkey.keylen,
+  rc = fscanf (fh, "%u %zu %zu %zu %zu %u", &tmpkey.etype, &tmpkey.keylen,
               &tmpkey.saltlen, &tmpkey.str2keyparamlen, &passwdlen,
               &tmpkey.priority);
   if (rc != 5 && rc != 6)
diff --git a/extra/pam_shishi/pam_shishi.c b/extra/pam_shishi/pam_shishi.c
index 0fa7ffe..59086b4 100644
--- a/extra/pam_shishi/pam_shishi.c
+++ b/extra/pam_shishi/pam_shishi.c
@@ -289,7 +289,7 @@ pam_sm_authenticate (pam_handle_t * pamh,
 done:
   if (h)
     shishi_done (h);
-  pam_set_data (pamh, "shishi_setcred_return", (void *) retval, NULL);
+  pam_set_data (pamh, "shishi_setcred_return", (void *) (intptr_t) retval, 
NULL);
   D (("done. [%s]", pam_strerror (pamh, retval)));
 
   return retval;
diff --git a/lib/asn1.c b/lib/asn1.c
index 65d30fb..7fc2d26 100644
--- a/lib/asn1.c
+++ b/lib/asn1.c
@@ -124,8 +124,9 @@ shishi_asn1_read_inline (Shishi * handle, Shishi_asn1 node,
                         const char *field, char *data, size_t * datalen)
 {
   int rc;
+  int len = (int) *datalen;
 
-  rc = asn1_read_value (node, field, (unsigned char *) data, (int *) datalen);
+  rc = asn1_read_value (node, field, (unsigned char *) data, &len);
   if (rc != ASN1_SUCCESS)
     {
       shishi_error_set (handle, asn1_strerror (rc));
@@ -137,6 +138,8 @@ shishi_asn1_read_inline (Shishi * handle, Shishi_asn1 node,
        return SHISHI_ASN1_ERROR;
     }
 
+  *datalen = len;
+
   return SHISHI_OK;
 }
 
@@ -402,7 +405,7 @@ shishi_asn1_write_bitstring (Shishi * handle, Shishi_asn1 
node,
 /**
  * shishi_asn1_done:
  * @handle: shishi handle as allocated by shishi_init().
  * @node: ASN.1 node to dellocate.
  *
  * Deallocate resources associated with ASN.1 structure.  Note that
  * the node must not be used after this call.
@@ -417,7 +420,7 @@ shishi_asn1_done (Shishi * handle, Shishi_asn1 node)
     {
       rc = asn1_delete_structure (&node);
       if (rc != ASN1_SUCCESS)
-       shishi_error_printf (handle, "Cannot dellocate ASN.1 structure: %s",
+       shishi_error_printf (handle, "Cannot deallocate ASN.1 structure: %s",
                             asn1_strerror (rc));
     }
 }
@@ -402,7 +405,7 @@ shishi_asn1_write_bitstring (Shishi * handle, Shishi_asn1 
  * shishi_asn1_done:
  * @handle: shishi handle as allocated by shishi_init().
- * @node: ASN.1 node to dellocate.
+ * @node: ASN.1 node to deallocate.
  *
  * Deallocate resources associated with ASN.1 structure.  Note that


hooks/post-receive
-- 
GNU shishi



reply via email to

[Prev in Thread] Current Thread [Next in Thread]